@@ -72,12 +72,15 @@ class Partition(NetBoxModel):
     size = models.PositiveIntegerField(
         verbose_name="Size (GB)"
     )
+    type = models.CharField(
+        max_length=255,
+    )
     description = models.CharField(
         max_length=255,
         blank=True,
     )
 
-    clone_fields = ["drive", "device", "size", "description"]
+    clone_fields = ["drive", "device", "size", "type", "description"]
 
     class Meta:
         ordering = ["size"]
