@@ -43,7 +43,7 @@ from netbox_storage.views import (
     PhysicalVolumeBulkEditView,
     PhysicalVolumeBulkDeleteView,
     PhysicalVolumeView,
-    PhysicalVolumeDeleteView,
+    PhysicalVolumeDeleteView, DrivePartitionListView,
 )
 
 app_name = "netbox_storage"
@@ -66,6 +66,7 @@ urlpatterns = [
         name="drive_changelog",
         kwargs={"model": Drive},
     ),
+    path("drive/<int:pk>/partition/", DrivePartitionListView.as_view(), name="drive_partitions"),
     #
     # Filesystem urls
     #
